# CiviCRM v5.x.0: Publish a release candidate

## Prerequisites

See [Prerequisites](any-prereq.md)

> __PENDING!__ _There is a draft command `forkify wf:rc` which combines more of these steps. It is commented-out.
> When doing the next release, you may want to polish/test it._

## 1: Sanity checks

* Note the original branch, such as `master`.
* Note the intended version, such as `5.1` or `5.3`. (In the rest of this document, we'll refer to `5.X`, but `5.X` should be adjusted to circumstance.)
* In `civicrm-core.git` repo, check that the code in `master` correctly references `5.X.alpha1`:
    * https://github.com/civicrm/civicrm-core/blob/master/xml/version.xml
    * https://github.com/civicrm/civicrm-core/blob/master/sql/civicrm_generated.mysql
    * https://github.com/civicrm/civicrm-core/tree/master/CRM/Upgrade/Incremental
* In Jenkins, review the scheduled tests for `master` and determine if anything should block the RC.
    * https://test.civicrm.org/job/CiviCRM-Core-Matrix/
    * https://test.civicrm.org/job/CiviCRM-Ext-Matrix/
    * https://test.civicrm.org/job/CiviCRM-E2E-Matrix/
    * https://test.civicrm.org/job/CiviCRM-D8-Matrix/

## 2: Bump version number on `master` to `5.X.beta1`

```bash
cd ~/src/master
forkify pull -A --ff-only master origin/master
./tools/bin/scripts/set-version.php 5.X.beta1 --commit
git push origin master
```

## 3: Make a branch

For each git repo, we want to create a new branch for 5.X.

| repo | folder| original branch | new branch |
|------|-------|-----------------|------------|
|civicrm-core|./|master|5.X|
|civicrm-packages|./packages/|master|5.X|
|civicrm-backdrop|./backdrop/|1.x-master|1.x-5.X|
|civicrm-drupal|./drupal/|6.x-master|6.x-5.X|
|civicrm-drupal|./drupal/|7.x-master|7.x-5.X|
|civicrm-drupal-8|./drupal-8/|master|5.X|
|civicrm-joomla|./joomla/|master|5.X|
|civicrm-wordpress|./WordPress/|master|5.X|

If you don't already have the repos in the correct folders, then you can:

* Create a suitable project (`civibuild create dist`) and look in `build/dist/src`, or...
* Login to `latest.civicrm.org` and use `~/src/master`.

Either way, you should get the current code and create the branches:

```bash
cd ~/src/master
forkify -A fetch origin
forkify -A branch 5.X origin/master
forkify -A push -u origin 5.X
```

> TIP: `forkify` can provide a preview (`--dry-run` aka `-N`) or an interactive confirmation (`--step` aka `-S`).

## 4: Setup automated processes

* Go to https://test.civicrm.org/job/CiviCRM-Core-Matrix/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-Core-Matrix-Timing/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-Core-Edge/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-E2E-Edge/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-Ext-Matrix/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-E2E-Matrix/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-D8-Matrix/configure
    * In the list of `CIVIVER`s, remove any old RC's. Add the current RC. (ex: `4.6 5.X master`)
* Go to https://test.civicrm.org/job/CiviCRM-Publish-Schedule/configure
    * In the list of `branchNames`, remove any old RC's. Add the current RC. (ex: `master 4.6 5.X`)
   
## 5: Publish tarballs

* Go to https://test.civicrm.org/job/CiviCRM-Publish/
* Check to see if the new branch is being built automatically. If not:
    * Login (if you haven't already)
    * Click "Build with parameters"
    * For the branch name, enter your chosen `5.X`.

## 6: Bump version number on `master` to  `5.Y.alpha1`

The original branch, "master", should continue development with the next version, e.g. "5.Y".

```bash
cd ~/src/master
git checkout master
git pull --ff-only origin master
./tools/bin/scripts/set-version.php 5.Y.alpha1 --commit
git push origin master
```
